---
title: '정산금을 자동으로 계산하는 수식은 어떻게 만들 수 있나요? '
category: 자주 묻는 질문 (일반 문의) > 파트너정산자동화 > 파트너정산자동화
seo:
  title: '정산금 계산 커스텀을 위한 수식 관리 '
  description: '메타 데이터로 정산 파라미터를 만들 수 있고 수식을 자유롭게 편집하여 정산금 계산을 자동화할 수 있습니다. '
  keywords:
    - 정산금계산, 메타데이터, 정산파라미터, 정산금자동계산, 정산시스템
tags:
  - 정산정책관리
  - 수식관리
pgCompanies:
  - 공통
searchTags:
  - 정산정책관리
  - 수식관리
  - 정산금계산
  - 정산 계산
datetime: 2023-12-31T15:00:00.000Z
---

<Callout content="포트원이 제공하는 기본 파라미터를 활용하여 정산금 자동 계산식을 만들 수 있습니다. 
우리 회사에서만 쓰는 정산 정책이 있어도, 원하는 파라미터를 만들어서 엑셀처럼 수식을 만들 수 있습니다." title="" />

### 정산금 자동 계산이란?

- 주문 금액, 결제 금액, 플랫폼 중개 수수료, PG 수수료 등 정산금을 자동으로 계산할 때 기본적으로 쓰이는 개념들을 파라미터로 제공하여 주문이 발생할 때 정산금을 자동으로 계산하도록 설정할 수 있는 기능입니다. ![](/uploads/파트너정산자동화/수식관리\(계산v2\).png)

### 자동 계산은 어떻게 설정할 수 있나요?

#### 기본 제공 파라미터

기본적으로 제공하는 파라미터는 아래와 같습니다.\
아래 파라미터를 활용하여 플랫폼 중개수수료, 추가수수료, 할인금 등 정산금을 구성하는 기본 요소에 대해서 어떻게 계산할지 수식을 저장할 수 있습니다.

- 주문금액
- 결제금액
- 결제금액부가세
- 결제금액부가세 부담금
- 할인금액 
- 할인부담금 
- 플랫폼중개수수료
- 플랫폼중개수수료부가세 부담금
- 정률
- 정액

#### 전체 정산금 계산 예시

- 플랫폼 중개 수수료 : 결제금액 \* 정률 (10%)
- 추가 수수료 : 결제금액 \* 정률 (3.2%)
- 정산금 = 주문금액 - 플랫폼중개수수료 - 추가수수료 (PG수수료)

### 소수점 올림, 내림, 반올림 처리도 가능한가요?

- 네, 각 수식마다 소수점 처리를 조정할 수 있도록 올림, 내림, 반올림 변수를 제공하고 있습니다.

### 우리 회사에 맞는 원하는 수식, 원하는 파라미터가 없는데 어떻게 처리할 수 있나요?

- 포트원 기본 제공 수식과 파라미터로 내부 정산 정책을 세팅할 수 없다면, 원하는 사용자 정의 수식과 정산 파라미터를 만들 수 있습니다. (2025년 2월 출시 예정)
- 주요 업데이트 사항
  - 사용자 정의 수식 생성
  - 정산 파라미터 생성 및 관리
  - 수식과 수식은 참조관계일 수 있음
  - 각 수식별 수수점 계산 방식 설정

### 추가 질문이 있으시다면?

아래 연락처로 언제든지 편히 문의해주세요.

<Callout content="기술 문의 지원 이메일
b2b.support@portone.io" />

###
